@@ -19,17 +19,17 @@ from contextlib import contextmanager
 from dataclasses import dataclass, field
 import enum
 import time
-
-import cx_Oracle
-from cx_Oracle import Connection
+import uuid
 
 import dbt.exceptions
-
 from dbt.adapters.base import Credentials
 from dbt.adapters.sql import SQLConnectionManager
 from dbt.contracts.connection import AdapterResponse
 from dbt.events import AdapterLogger
 
+from dbt.version import __version__ as dbt_version
+from dbt.adapters.oracle.connection_helper import oracledb, SQLNET_ORA_CONFIG
+
 logger = AdapterLogger("oracle")
 
 
@@ -72,6 +72,10 @@ class OracleAdapterCredentials(Credentials):
     cclass: Optional[str] = None
     purity: Optional[str] = None
 
+    # Connection retry params
+    retry_count: Optional[int] = 1
+    retry_delay: Optional[int] = 3
+
 
     _ALIASES = {
         'dbname': 'database',
@@ -95,7 +99,8 @@ class OracleAdapterCredentials(Credentials):
             'protocol', 'host', 'port', 'tns_name',
             'service', 'connection_string',
             'shardingkey', 'supershardingkey',
-            'cclass', 'purity'
+            'cclass', 'purity', 'retry_count',
+            'retry_delay'
         )
 
     @classmethod
@@ -127,7 +132,7 @@ class OracleAdapterCredentials(Credentials):
             return self.connection_string
 
         # Assume host connection method OracleConnectionMethod.HOST and necessary parameters are defined
-        return f'{self.protocol}://{self.host}:{self.port}/{self.service}'
+        return f'{self.protocol}://{self.host}:{self.port}/{self.service}?retry_count={self.retry_count}&retry_delay={self.retry_delay}'
 
 
 class OracleAdapterConnectionManager(SQLConnectionManager):
@@ -163,17 +168,23 @@ class OracleAdapterConnectionManager(SQLConnectionManager):
         if credentials.purity:
             purity = credentials.purity.lower()
             if credentials.purity == 'new':
-                conn_config['purity'] = cx_Oracle.ATTR_PURITY_NEW
+                conn_config['purity'] = oracledb.ATTR_PURITY_NEW
             elif purity == 'self':
-                conn_config['purity'] = cx_Oracle.ATTR_PURITY_SELF
+                conn_config['purity'] = oracledb.ATTR_PURITY_SELF
             elif purity == 'default':
-                conn_config['purity'] = cx_Oracle.ATTR_PURITY_DEFAULT
+                conn_config['purity'] = oracledb.ATTR_PURITY_DEFAULT
+
+        if SQLNET_ORA_CONFIG is not None:
+            conn_config.update(SQLNET_ORA_CONFIG)
 
         try:
-            handle = cx_Oracle.connect(**conn_config)
+            handle = oracledb.connect(**conn_config)
+            # client_identifier and module are saved in corresponding columns in v$session
+            handle.module = f'dbt-{dbt_version}'
+            handle.client_identifier = f'dbt-oracle-client-{uuid.uuid4()}'
             connection.handle = handle
             connection.state = 'open'
-        except cx_Oracle.DatabaseError as e:
+        except oracledb.DatabaseError as e:
             logger.info(f"Got an error when attempting to open an Oracle "
                         f"connection: '{e}'")
             connection.handle = None
@@ -191,7 +202,7 @@ class OracleAdapterConnectionManager(SQLConnectionManager):
         logger.info("Cancelling query '{}' ".format(connection_name))
 
         try:
-            Connection.close(oracle_connection)
+            oracledb.Connection.close(oracle_connection)
         except Exception as e:
             logger.error('Error closing connection for cancel request')
             raise Exception(str(e))
@@ -215,13 +226,13 @@ class OracleAdapterConnectionManager(SQLConnectionManager):
         try:
             yield
 
-        except cx_Oracle.DatabaseError as e:
+        except oracledb.DatabaseError as e:
             logger.info('Oracle error: {}'.format(str(e)))
 
             try:
                 # attempt to release the connection
                 self.release()
-            except cx_Oracle.Error:
+            except oracledb.Error:
                 logger.info("Failed to release connection!")
                 pass
 
@@ -248,7 +259,7 @@ class OracleAdapterConnectionManager(SQLConnectionManager):
         auto_begin: bool = True,
         bindings: Optional[Any] = {},
         abridge_sql_log: bool = False
-    ) -> Tuple[Connection, Any]:
+    ) -> Tuple[oracledb.Connection, Any]:
         connection = self.get_thread_connection()
         if auto_begin and connection.transaction_open is False:
             self.begin()
@@ -264,10 +275,8 @@ class OracleAdapterConnectionManager(SQLConnectionManager):
 
             logger.debug(f'On {connection.name}: f{log_sql}')
             pre = time.time()
-
             cursor = connection.handle.cursor()
             cursor.execute(sql, bindings)
-            connection.handle.commit()
             logger.debug(f"SQL status: {self.get_status(cursor)} in {(time.time() - pre)} seconds")
             return connection, cursor
 
