@@ -77,9 +77,14 @@
         {{ return([false, query_columns]) }}
     {%- endif -%}
     {# handle any schema changes #}
+    {% set node_database = node.database %}
+    {% if node_database == 'None' or model_database is undefined or model_database is none %}
+        {% set node_database = get_database_name() %}
+    {% endif %}
     {%- set target_table = node.get('alias', node.get('name')) -%}
-    {%- set target_relation = adapter.get_relation(database=node.database, schema=node.schema, identifier=target_table) -%}
-    {%- set existing_cols = get_columns_in_query('select * from ' ~ target_relation.quote(schema=False, identifier=False)) -%}
+
+    {%- set target_relation = adapter.get_relation(database=node_database, schema=node.schema, identifier=target_table) -%}
+    {%- set existing_cols = get_columns_in_query('select * from ' ~ target_relation) -%}
     {%- set ns = namespace() -%} {# handle for-loop scoping with a namespace #}
     {%- set ns.column_added = false -%}
 
@@ -93,3 +98,23 @@
     {%- endfor -%}
     {{ return([ns.column_added, intersection]) }}
 {%- endmacro %}
+
+{% macro snapshot_timestamp_strategy(node, snapshotted_rel, current_rel, config, target_exists) %}
+    {% set primary_key = config['unique_key'] %}
+    {% set updated_at = config['updated_at'] %}
+    {% set invalidate_hard_deletes = config.get('invalidate_hard_deletes', false) %}
+
+    {% set row_changed_expr -%}
+        ({{ snapshotted_rel }}.dbt_valid_from < {{ current_rel }}.{{ updated_at }})
+    {%- endset %}
+    {# updated_at should be cast as timestamp because in hash computation "CAST(date as VARCHAR)" truncates time fields  #}
+    {% set scd_id_expr = snapshot_hash_arguments([primary_key, 'CAST(' ~ updated_at ~ ' AS TIMESTAMP)']) %}
+
+    {% do return({
+        "unique_key": primary_key,
+        "updated_at": updated_at,
+        "row_changed": row_changed_expr,
+        "scd_id": scd_id_expr,
+        "invalidate_hard_deletes": invalidate_hard_deletes
+    }) %}
+{% endmacro %}
